@@ -72,6 +72,7 @@ class CamelModel(BaseModel):
 class TestRunConfigModel(CamelModel):
     environment: Optional[str] = None
     build: Optional[str] = None
+    treat_skips_as_failures: bool = True
 
 
 class MilestoneModel(CamelModel):
@@ -89,6 +90,11 @@ class NotificationTargetModel(CamelModel):
     value: str
 
 
+class NotificationsModel(CamelModel):
+    notify_on_each_failure: bool = False
+    targets: Optional[List[NotificationTargetModel]] = None
+
+
 class StartTestRunModel(CamelModel):
     name: str
     framework: str
@@ -98,7 +104,7 @@ class StartTestRunModel(CamelModel):
     config: Optional[TestRunConfigModel] = None
     milestone: Optional[MilestoneModel] = None
     ci_context: Optional[CiContextModel] = None
-    notification_targets: Optional[List[NotificationTargetModel]] = None
+    notifications: Optional[NotificationsModel] = None
 
 
 class LabelModel(CamelModel):
@@ -149,12 +155,17 @@ class FinishTestSessionModel(CamelModel):
     test_ids: List[int] = []
 
 
+class AttachTestsToSessionModel(CamelModel):
+    test_ids: List[int] = []
+
+
 class ArtifactReferenceModel(CamelModel):
     name: str
     value: str
 
 
 class TestModel(CamelModel):
+    id: int
     name: str
     correlation_data: Optional[CorrelationDataModel]
     status: str
@@ -168,3 +179,8 @@ class RerunDataModel(CamelModel):
     reason: Optional[str]
     run_only_specific_tests: bool
     tests_to_run: List[TestModel]
+
+
+class PlatformModel(CamelModel):
+    name: str
+    version: Optional[str]
