@@ -254,18 +254,14 @@ class ReportingService:
             return None
 
         return zebrunner_session_id
-    
+
     def add_test_to_session(self, zebrunner_session_id: str, related_tests: List[int]) -> None:
         if not zebrunner_context.test_run_is_active:
             return
 
         self.authorize()
         try:
-            self.api.add_tests_to_session(
-                zebrunner_context.test_run_id,
-                zebrunner_session_id,
-                related_tests
-            )
+            self.api.add_tests_to_session(zebrunner_context.test_run_id, zebrunner_session_id, related_tests)
         except AgentApiError as e:
             logging.error("failed to add tests to session", exc_info=e)
 
